"""Constants used across the PyFskElec client library."""

from __future__ import annotations

DEFAULT_BASE_URL = "https://api.srnservices.net"
DEFAULT_CLIENT_ID = "android_mirhino"
DEFAULT_CLIENT_SECRET = (
    "2zvWxa^YfJ8uBuWL#k6Bmtxs$4&hP3D@fVDdW3Hc07FW2JJqF6mk*GCCI!$&eB4v"
)
DEFAULT_TIMEOUT = 20.0
DEFAULT_USER_AGENT = "Dart/3.2 (dart:io)"
DEFAULT_APP_VERSION = "5.2.3|1417"
